@@ -194,14 +194,14 @@ sample_polar <- function(param, grid_size, range_max, project, ylim, xlim, k = 4
   } else {
     elev <- 0
   }
+
   # get scan parameter indices, and extract data
   index <- polar_to_index(
     cartesian_to_polar(gridTopoCrds, elev, k = k, lat = attributes(param)$geo$lat, re = re, rp = rp),
     rangebin = attributes(param)$geo$rscale,
     azimbin = attributes(param)$geo$ascale,
-    azimstart <- max(c(0, attributes(param)$geo$astart), na.rm = TRUE),
-    rangestart <- max(c(0, attributes(param)$geo$rstart), na.rm = TRUE)
-
+    rangestart = max(c(0, attributes(param)$geo$rstart), na.rm = TRUE),
+    azimstart = max(c(0, attributes(param)$geo$astart), na.rm = TRUE)
   )
 
   # set indices outside the scan's matrix to NA
